@@ -2,5 +2,5 @@
   RFver <- read.dcf(file=system.file("DESCRIPTION", package=pkgname),
                     fields="Version")
   packageStartupMessage(paste(pkgname, RFver))
-  packageStartupMessage("Discretized Beta Regression for Survey-Response Analysis")
+  packageStartupMessage("Bayesian Discretized Beta Regression for the Analysis of Ratings Data")
 }
